summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_html_live_status.py
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2015-11-25 19:16:44 +0100
committerHolger Levsen <holger@layer-acht.org>2015-11-25 19:16:44 +0100
commit3fa8572b959ce4fa253cd430d71a3c222971f106 (patch)
tree6e72dd206651ced0437bacb7918245d8c20db8b2 /bin/reproducible_html_live_status.py
parent3bf156d9a03753c1ef2e4ed77eebe7ec9c713b65 (diff)
downloadjenkins.debian.net-3fa8572b959ce4fa253cd430d71a3c222971f106.tar.xz
reproducible: add 15th armhf build job
Diffstat (limited to 'bin/reproducible_html_live_status.py')
-rwxr-xr-xbin/reproducible_html_live_status.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_html_live_status.py b/bin/reproducible_html_live_status.py
index 86439549..6d51746d 100755
--- a/bin/reproducible_html_live_status.py
+++ b/bin/reproducible_html_live_status.py
@@ -66,8 +66,8 @@ def generate_live_status_table(arch):
counter = 0
for row in rows:
counter += 1
- # FIXME: the numbers 32 and 14 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
- if ( arch == 'amd64' and counter > 32 ) or ( arch == 'armhf' and counter > 14 ):
+ # FIXME: the numbers 32 and 15 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
+ if ( arch == 'amd64' and counter > 32 ) or ( arch == 'armhf' and counter > 15 ):
html += '<tr><td colspan="10">There are more builds marked as currently building in the database than there are ' + arch + ' build jobs. This does not compute, please investigate and fix the cause.</td></tr>'
suite = row[1]
arch = row[2]